@@ -3,6 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
+our $VERSION = '0.15';
 use Carp qw(croak);
 use Time::HiRes qw(sleep);
 use IPC::ConcurrencyLimit;
@@ -52,7 +53,7 @@ sub get_lock {
   # Convert retries to a sub if it's not one already
   if ( ref $self->{retries} ne "CODE" ) {
       my $max_retries = $self->{retries};
-      $self->{retries} = sub { return $_[0] != $max_retries + 1 };
+      $self->{retries} = sub { return $_[0] <= $max_retries };
   }
 
   my $id = $main_lock->get_lock;
@@ -136,6 +137,7 @@ IPC::ConcurrencyLimit::WithStandby - IPC::ConcurrencyLimit with an additional st
       standby_max_procs => 3,
     );
     
+    # NOTE: when $limit goes out of scope, the lock is released
     my $id = $limit->get_lock;
     if (not $id) {
       warn "Got none of the worker locks. Exiting.";
@@ -207,6 +209,13 @@ table before using this feature was shown as C<foo.pl - standby> while
 in standby mode and as C<foo.pl> after getting a main worker lock.
 Note the curiously stripped C<perl> prefix.
 
+=head1 WARNING!
+
+Make sure the variable holding the lock remains in scope at all times,
+otherwise the lock will be released, resulting in process churn and potential
+double work. This is the most common reason for having several concurrent
+processes running when only one is expected to be alive.
+
 =head1 AUTHOR
 
 Steffen Mueller, C<smueller@cpan.org>
